# beanie

Beanie - the Ruby gem for the Beanie ERP API

An API specification for interacting with the Beanie ERP system

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.2
- Package version: 0.2.2
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build beanie.gemspec
```

Then either install the gem locally:

```shell
gem install ./beanie-0.2.2.gem
```
(for development, run `gem install --dev ./beanie-0.2.2.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'beanie', '~> 0.2.2'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/altoyield/ruby-beanieclient, then add the following in the Gemfile:

    gem 'beanie', :git => 'https://github.com/altoyield/ruby-beanieclient.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'beanie'

# Setup authorization
Beanie.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['ApiKey'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['ApiKey'] = 'Bearer'
end

api_instance = Beanie::AddressBlockApi.new

address_blocks = Beanie::AddressBlockInput.new # AddressBlockInput | Address block to add to the system


begin
  result = api_instance.add_address_block(address_blocks)
  p result
rescue Beanie::ApiError => e
  puts "Exception when calling AddressBlockApi->add_address_block: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://bean.ie*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Beanie::AddressBlockApi* | [**add_address_block**](docs/AddressBlockApi.md#add_address_block) | **POST** /address_blocks | 
*Beanie::AddressBlockApi* | [**find_address_block_by_id**](docs/AddressBlockApi.md#find_address_block_by_id) | **GET** /address_blocks/{id} | Find Address block by ID
*Beanie::AddressBlockApi* | [**find_address_blocks**](docs/AddressBlockApi.md#find_address_blocks) | **GET** /address_blocks | All address block
*Beanie::BankAccountApi* | [**add_bank_account**](docs/BankAccountApi.md#add_bank_account) | **POST** /bank_accounts | 
*Beanie::BankAccountApi* | [**find_bank_account_by_id**](docs/BankAccountApi.md#find_bank_account_by_id) | **GET** /bank_accounts/{id} | Find Bank Account by ID
*Beanie::BankAccountApi* | [**find_bank_accounts**](docs/BankAccountApi.md#find_bank_accounts) | **GET** /bank_accounts | All bank accounts
*Beanie::BankStatementApi* | [**add_bank_statement**](docs/BankStatementApi.md#add_bank_statement) | **POST** /bank_statements | 
*Beanie::BankStatementApi* | [**find_bank_statement_by_id**](docs/BankStatementApi.md#find_bank_statement_by_id) | **GET** /bank_statements/{id} | Find Bank statement by ID
*Beanie::BankStatementApi* | [**find_bank_statements**](docs/BankStatementApi.md#find_bank_statements) | **GET** /bank_statements | All bank statement
*Beanie::BeanieTaskApi* | [**add_beanie_task**](docs/BeanieTaskApi.md#add_beanie_task) | **POST** /beanie_tasks | 
*Beanie::BeanieTaskApi* | [**find_beanie_task_by_id**](docs/BeanieTaskApi.md#find_beanie_task_by_id) | **GET** /beanie_tasks/{id} | Find Beanie task by ID
*Beanie::BeanieTaskApi* | [**find_beanie_tasks**](docs/BeanieTaskApi.md#find_beanie_tasks) | **GET** /beanie_tasks | All beanie task
*Beanie::BillOfMaterialsApi* | [**add_bill_of_material**](docs/BillOfMaterialsApi.md#add_bill_of_material) | **POST** /bill_of_materials | 
*Beanie::BillOfMaterialsApi* | [**find_bill_of_material_by_id**](docs/BillOfMaterialsApi.md#find_bill_of_material_by_id) | **GET** /bill_of_materials/{id} | Find Bill of Materials by ID
*Beanie::BillOfMaterialsApi* | [**find_bill_of_materials**](docs/BillOfMaterialsApi.md#find_bill_of_materials) | **GET** /bill_of_materials | All bill of materials
*Beanie::BillableApi* | [**add_billable**](docs/BillableApi.md#add_billable) | **POST** /billables | 
*Beanie::BillableApi* | [**find_billable_by_id**](docs/BillableApi.md#find_billable_by_id) | **GET** /billables/{id} | Find Billable record by ID
*Beanie::BillableApi* | [**find_billables**](docs/BillableApi.md#find_billables) | **GET** /billables | All billable record
*Beanie::CompanyApi* | [**find_company_by_id**](docs/CompanyApi.md#find_company_by_id) | **GET** /companies/{id} | Find Company details by ID
*Beanie::CustomerApi* | [**add_customer**](docs/CustomerApi.md#add_customer) | **POST** /customers | 
*Beanie::CustomerApi* | [**find_customer_by_id**](docs/CustomerApi.md#find_customer_by_id) | **GET** /customers/{id} | Find Customer by ID
*Beanie::CustomerApi* | [**find_customers**](docs/CustomerApi.md#find_customers) | **GET** /customers | All customer
*Beanie::CustomerAddressApi* | [**add_customer_address**](docs/CustomerAddressApi.md#add_customer_address) | **POST** /customer_addresses | 
*Beanie::CustomerAddressApi* | [**find_customer_address_by_id**](docs/CustomerAddressApi.md#find_customer_address_by_id) | **GET** /customer_addresses/{id} | Find Customer address by ID
*Beanie::CustomerAddressApi* | [**find_customer_addresses**](docs/CustomerAddressApi.md#find_customer_addresses) | **GET** /customer_addresses | All customer address
*Beanie::DeliveryNoteApi* | [**add_delivery_note**](docs/DeliveryNoteApi.md#add_delivery_note) | **POST** /delivery_notes | 
*Beanie::DeliveryNoteApi* | [**find_delivery_note_by_id**](docs/DeliveryNoteApi.md#find_delivery_note_by_id) | **GET** /delivery_notes/{id} | Find Delivery note by ID
*Beanie::DeliveryNoteApi* | [**find_delivery_notes**](docs/DeliveryNoteApi.md#find_delivery_notes) | **GET** /delivery_notes | All delivery note
*Beanie::DocumentApi* | [**add_document**](docs/DocumentApi.md#add_document) | **POST** /documents | 
*Beanie::DocumentApi* | [**find_document_by_id**](docs/DocumentApi.md#find_document_by_id) | **GET** /documents/{id} | Find Document by ID
*Beanie::DocumentApi* | [**find_documents**](docs/DocumentApi.md#find_documents) | **GET** /documents | All document
*Beanie::FixedAssetApi* | [**add_fixed_asset**](docs/FixedAssetApi.md#add_fixed_asset) | **POST** /fixed_assets | 
*Beanie::FixedAssetApi* | [**find_fixed_asset_by_id**](docs/FixedAssetApi.md#find_fixed_asset_by_id) | **GET** /fixed_assets/{id} | Find Fixed asset by ID
*Beanie::FixedAssetApi* | [**find_fixed_assets**](docs/FixedAssetApi.md#find_fixed_assets) | **GET** /fixed_assets | All fixed asset
*Beanie::JournalApi* | [**add_journal**](docs/JournalApi.md#add_journal) | **POST** /journals | 
*Beanie::JournalApi* | [**find_journal_by_id**](docs/JournalApi.md#find_journal_by_id) | **GET** /journals/{id} | Find Journal by ID
*Beanie::JournalApi* | [**find_journals**](docs/JournalApi.md#find_journals) | **GET** /journals | All journal
*Beanie::NominalAccountApi* | [**add_nominal_account**](docs/NominalAccountApi.md#add_nominal_account) | **POST** /nominal_accounts | 
*Beanie::NominalAccountApi* | [**find_nominal_account_by_id**](docs/NominalAccountApi.md#find_nominal_account_by_id) | **GET** /nominal_accounts/{id} | Find Nominal account by ID
*Beanie::NominalAccountApi* | [**find_nominal_accounts**](docs/NominalAccountApi.md#find_nominal_accounts) | **GET** /nominal_accounts | All nominal account
*Beanie::NominalAccountCategoryApi* | [**add_nominal_account_category**](docs/NominalAccountCategoryApi.md#add_nominal_account_category) | **POST** /nominal_account_categories | 
*Beanie::NominalAccountCategoryApi* | [**find_nominal_account_categories**](docs/NominalAccountCategoryApi.md#find_nominal_account_categories) | **GET** /nominal_account_categories | All nominal account category
*Beanie::NominalAccountCategoryApi* | [**find_nominal_account_category_by_id**](docs/NominalAccountCategoryApi.md#find_nominal_account_category_by_id) | **GET** /nominal_account_categories/{id} | Find Nominal account category by ID
*Beanie::ProductApi* | [**add_product**](docs/ProductApi.md#add_product) | **POST** /products | 
*Beanie::ProductApi* | [**find_product_by_id**](docs/ProductApi.md#find_product_by_id) | **GET** /products/{id} | Find Product by ID
*Beanie::ProductApi* | [**find_products**](docs/ProductApi.md#find_products) | **GET** /products | All product
*Beanie::ProductCategoryApi* | [**add_product_category**](docs/ProductCategoryApi.md#add_product_category) | **POST** /product_categories | 
*Beanie::ProductCategoryApi* | [**find_product_categories**](docs/ProductCategoryApi.md#find_product_categories) | **GET** /product_categories | All product category
*Beanie::ProductCategoryApi* | [**find_product_category_by_id**](docs/ProductCategoryApi.md#find_product_category_by_id) | **GET** /product_categories/{id} | Find Product category by ID
*Beanie::ProductPriceApi* | [**add_product_price**](docs/ProductPriceApi.md#add_product_price) | **POST** /product_prices | 
*Beanie::ProductPriceApi* | [**find_product_price_by_id**](docs/ProductPriceApi.md#find_product_price_by_id) | **GET** /product_prices/{id} | Find Product price by ID
*Beanie::ProductPriceApi* | [**find_product_prices**](docs/ProductPriceApi.md#find_product_prices) | **GET** /product_prices | All product price
*Beanie::ProductVariantApi* | [**add_product_variant**](docs/ProductVariantApi.md#add_product_variant) | **POST** /product_variants | 
*Beanie::ProductVariantApi* | [**find_product_variant_by_id**](docs/ProductVariantApi.md#find_product_variant_by_id) | **GET** /product_variants/{id} | Find Product variant by ID
*Beanie::ProductVariantApi* | [**find_product_variants**](docs/ProductVariantApi.md#find_product_variants) | **GET** /product_variants | All product variant
*Beanie::ProductionOrderApi* | [**add_production_order**](docs/ProductionOrderApi.md#add_production_order) | **POST** /production_orders | 
*Beanie::ProductionOrderApi* | [**find_production_order_by_id**](docs/ProductionOrderApi.md#find_production_order_by_id) | **GET** /production_orders/{id} | Find Production order by ID
*Beanie::ProductionOrderApi* | [**find_production_orders**](docs/ProductionOrderApi.md#find_production_orders) | **GET** /production_orders | All production order
*Beanie::PurchaseInvoiceApi* | [**add_purchase_invoice**](docs/PurchaseInvoiceApi.md#add_purchase_invoice) | **POST** /purchase_invoices | 
*Beanie::PurchaseInvoiceApi* | [**find_purchase_invoice_by_id**](docs/PurchaseInvoiceApi.md#find_purchase_invoice_by_id) | **GET** /purchase_invoices/{id} | Find Purchase invoice by ID
*Beanie::PurchaseInvoiceApi* | [**find_purchase_invoices**](docs/PurchaseInvoiceApi.md#find_purchase_invoices) | **GET** /purchase_invoices | All purchase invoice
*Beanie::PurchaseOrderApi* | [**add_purchase_order**](docs/PurchaseOrderApi.md#add_purchase_order) | **POST** /purchase_orders | 
*Beanie::PurchaseOrderApi* | [**find_purchase_order_by_id**](docs/PurchaseOrderApi.md#find_purchase_order_by_id) | **GET** /purchase_orders/{id} | Find Purchase order by ID
*Beanie::PurchaseOrderApi* | [**find_purchase_orders**](docs/PurchaseOrderApi.md#find_purchase_orders) | **GET** /purchase_orders | All purchase order
*Beanie::ReceivedGoodsApi* | [**add_received_goods**](docs/ReceivedGoodsApi.md#add_received_goods) | **POST** /received_goods | 
*Beanie::ReceivedGoodsApi* | [**find_received_goods**](docs/ReceivedGoodsApi.md#find_received_goods) | **GET** /received_goods | All received goods
*Beanie::ReceivedGoodsApi* | [**find_received_goods_by_id**](docs/ReceivedGoodsApi.md#find_received_goods_by_id) | **GET** /received_goods/{id} | Find Received goods by ID
*Beanie::SalesInvoiceApi* | [**add_sales_invoice**](docs/SalesInvoiceApi.md#add_sales_invoice) | **POST** /sales_invoices | 
*Beanie::SalesInvoiceApi* | [**find_sales_invoice_by_id**](docs/SalesInvoiceApi.md#find_sales_invoice_by_id) | **GET** /sales_invoices/{id} | Find Sales invoice by ID
*Beanie::SalesInvoiceApi* | [**find_sales_invoices**](docs/SalesInvoiceApi.md#find_sales_invoices) | **GET** /sales_invoices | All sales invoice
*Beanie::SalesOrderApi* | [**add_sales_order**](docs/SalesOrderApi.md#add_sales_order) | **POST** /sales_orders | 
*Beanie::SalesOrderApi* | [**find_sales_order**](docs/SalesOrderApi.md#find_sales_order) | **GET** /sales_orders | All sales order
*Beanie::SalesOrderApi* | [**find_sales_order_by_id**](docs/SalesOrderApi.md#find_sales_order_by_id) | **GET** /sales_orders/{id} | Find Sales order by ID
*Beanie::ShippingCentreApi* | [**add_shipping_centre**](docs/ShippingCentreApi.md#add_shipping_centre) | **POST** /shipping_centres | 
*Beanie::ShippingCentreApi* | [**find_shipping_centre_by_id**](docs/ShippingCentreApi.md#find_shipping_centre_by_id) | **GET** /shipping_centres/{id} | Find Shipping centre by ID
*Beanie::ShippingCentreApi* | [**find_shipping_centres**](docs/ShippingCentreApi.md#find_shipping_centres) | **GET** /shipping_centres | All shipping centre
*Beanie::StockAdjustmentApi* | [**add_stock_adjustment**](docs/StockAdjustmentApi.md#add_stock_adjustment) | **POST** /stock_adjustments | 
*Beanie::StockAdjustmentApi* | [**find_stock_adjustment_by_id**](docs/StockAdjustmentApi.md#find_stock_adjustment_by_id) | **GET** /stock_adjustments/{id} | Find Stock adjustment by ID
*Beanie::StockAdjustmentApi* | [**find_stock_adjustments**](docs/StockAdjustmentApi.md#find_stock_adjustments) | **GET** /stock_adjustments | All stock adjustment
*Beanie::StockCategoryApi* | [**add_stock_category**](docs/StockCategoryApi.md#add_stock_category) | **POST** /stock_categories | 
*Beanie::StockCategoryApi* | [**find_stock_categories**](docs/StockCategoryApi.md#find_stock_categories) | **GET** /stock_categories | All stock category
*Beanie::StockCategoryApi* | [**find_stock_category_by_id**](docs/StockCategoryApi.md#find_stock_category_by_id) | **GET** /stock_categories/{id} | Find Stock category by ID
*Beanie::StockImageApi* | [**add_stock_image**](docs/StockImageApi.md#add_stock_image) | **POST** /stock_images | 
*Beanie::StockImageApi* | [**find_stock_image_by_id**](docs/StockImageApi.md#find_stock_image_by_id) | **GET** /stock_images/{id} | Find Stock image by ID
*Beanie::StockImageApi* | [**find_stock_images**](docs/StockImageApi.md#find_stock_images) | **GET** /stock_images | All stock image
*Beanie::StockItemApi* | [**add_stock_item**](docs/StockItemApi.md#add_stock_item) | **POST** /stock_items | 
*Beanie::StockItemApi* | [**find_stock_item_by_id**](docs/StockItemApi.md#find_stock_item_by_id) | **GET** /stock_items/{id} | Find Stock item by ID
*Beanie::StockItemApi* | [**find_stock_items**](docs/StockItemApi.md#find_stock_items) | **GET** /stock_items | All stock item
*Beanie::StockLocationApi* | [**add_stock_location**](docs/StockLocationApi.md#add_stock_location) | **POST** /stock_locations | 
*Beanie::StockLocationApi* | [**find_stock_location_by_id**](docs/StockLocationApi.md#find_stock_location_by_id) | **GET** /stock_locations/{id} | Find Stock location by ID
*Beanie::StockLocationApi* | [**find_stock_locations**](docs/StockLocationApi.md#find_stock_locations) | **GET** /stock_locations | All stock location
*Beanie::StockSupplierApi* | [**add_stock_supplier**](docs/StockSupplierApi.md#add_stock_supplier) | **POST** /stock_suppliers | 
*Beanie::StockSupplierApi* | [**find_stock_supplier_by_id**](docs/StockSupplierApi.md#find_stock_supplier_by_id) | **GET** /stock_suppliers/{id} | Find Stock supplier by ID
*Beanie::StockSupplierApi* | [**find_stock_suppliers**](docs/StockSupplierApi.md#find_stock_suppliers) | **GET** /stock_suppliers | All stock supplier
*Beanie::SupplierApi* | [**add_supplier**](docs/SupplierApi.md#add_supplier) | **POST** /suppliers | 
*Beanie::SupplierApi* | [**find_supplier_by_id**](docs/SupplierApi.md#find_supplier_by_id) | **GET** /suppliers/{id} | Find Supplier by ID
*Beanie::SupplierApi* | [**find_suppliers**](docs/SupplierApi.md#find_suppliers) | **GET** /suppliers | All supplier
*Beanie::SupplierAddressApi* | [**add_supplier_address**](docs/SupplierAddressApi.md#add_supplier_address) | **POST** /supplier_addresses | 
*Beanie::SupplierAddressApi* | [**find_supplier_address_by_id**](docs/SupplierAddressApi.md#find_supplier_address_by_id) | **GET** /supplier_addresses/{id} | Find Supplier address by ID
*Beanie::SupplierAddressApi* | [**find_supplier_addresses**](docs/SupplierAddressApi.md#find_supplier_addresses) | **GET** /supplier_addresses | All supplier address
*Beanie::VatRecordApi* | [**add_vat_record**](docs/VatRecordApi.md#add_vat_record) | **POST** /vat_records | 
*Beanie::VatRecordApi* | [**find_vat_record_by_id**](docs/VatRecordApi.md#find_vat_record_by_id) | **GET** /vat_records/{id} | Find VAT record by ID
*Beanie::VatRecordApi* | [**find_vat_records**](docs/VatRecordApi.md#find_vat_records) | **GET** /vat_records | All vat record
*Beanie::VatReturnApi* | [**add_vat_return**](docs/VatReturnApi.md#add_vat_return) | **POST** /vat_returns | 
*Beanie::VatReturnApi* | [**find_vat_return_by_id**](docs/VatReturnApi.md#find_vat_return_by_id) | **GET** /vat_returns/{id} | Find VAT return by ID
*Beanie::VatReturnApi* | [**find_vat_returns**](docs/VatReturnApi.md#find_vat_returns) | **GET** /vat_returns | All vat return
*Beanie::WorkCentreApi* | [**add_work_centre**](docs/WorkCentreApi.md#add_work_centre) | **POST** /work_centres | 
*Beanie::WorkCentreApi* | [**find_work_centre_by_id**](docs/WorkCentreApi.md#find_work_centre_by_id) | **GET** /work_centres/{id} | Find Work centre by ID
*Beanie::WorkCentreApi* | [**find_work_centres**](docs/WorkCentreApi.md#find_work_centres) | **GET** /work_centres | All work centre
*Beanie::WorkCentreGroupApi* | [**add_work_centre_group**](docs/WorkCentreGroupApi.md#add_work_centre_group) | **POST** /work_centre_groups | 
*Beanie::WorkCentreGroupApi* | [**find_work_centre_group_by_id**](docs/WorkCentreGroupApi.md#find_work_centre_group_by_id) | **GET** /work_centre_groups/{id} | Find Work centre group by ID
*Beanie::WorkCentreGroupApi* | [**find_work_centre_groups**](docs/WorkCentreGroupApi.md#find_work_centre_groups) | **GET** /work_centre_groups | All work centre group


## Documentation for Models

 - [Beanie::AddressBlock](docs/AddressBlock.md)
 - [Beanie::BankAccountInput](docs/BankAccountInput.md)
 - [Beanie::BankStatement](docs/BankStatement.md)
 - [Beanie::BankStatementData](docs/BankStatementData.md)
 - [Beanie::BeanieTask](docs/BeanieTask.md)
 - [Beanie::BillOfMaterial](docs/BillOfMaterial.md)
 - [Beanie::Billable](docs/Billable.md)
 - [Beanie::BomItem](docs/BomItem.md)
 - [Beanie::Company](docs/Company.md)
 - [Beanie::Customer](docs/Customer.md)
 - [Beanie::CustomerAddress](docs/CustomerAddress.md)
 - [Beanie::CustomerLedger](docs/CustomerLedger.md)
 - [Beanie::CustomerNote](docs/CustomerNote.md)
 - [Beanie::DeliveryNote](docs/DeliveryNote.md)
 - [Beanie::DeliveryNoteItem](docs/DeliveryNoteItem.md)
 - [Beanie::Document](docs/Document.md)
 - [Beanie::ErrorModel](docs/ErrorModel.md)
 - [Beanie::FixedAsset](docs/FixedAsset.md)
 - [Beanie::Journal](docs/Journal.md)
 - [Beanie::JournalItem](docs/JournalItem.md)
 - [Beanie::NominalAccount](docs/NominalAccount.md)
 - [Beanie::NominalAccountCategory](docs/NominalAccountCategory.md)
 - [Beanie::Product](docs/Product.md)
 - [Beanie::ProductCategory](docs/ProductCategory.md)
 - [Beanie::ProductPrice](docs/ProductPrice.md)
 - [Beanie::ProductVariant](docs/ProductVariant.md)
 - [Beanie::ProductionOrder](docs/ProductionOrder.md)
 - [Beanie::ProductionOrderLog](docs/ProductionOrderLog.md)
 - [Beanie::PurchaseInvoice](docs/PurchaseInvoice.md)
 - [Beanie::PurchaseOrder](docs/PurchaseOrder.md)
 - [Beanie::PurchaseOrderItem](docs/PurchaseOrderItem.md)
 - [Beanie::ReceivedGoods](docs/ReceivedGoods.md)
 - [Beanie::SalesInvoice](docs/SalesInvoice.md)
 - [Beanie::SalesInvoiceItem](docs/SalesInvoiceItem.md)
 - [Beanie::SalesOrder](docs/SalesOrder.md)
 - [Beanie::SalesOrderItem](docs/SalesOrderItem.md)
 - [Beanie::ShippingCentre](docs/ShippingCentre.md)
 - [Beanie::StockAdjustment](docs/StockAdjustment.md)
 - [Beanie::StockCategory](docs/StockCategory.md)
 - [Beanie::StockImage](docs/StockImage.md)
 - [Beanie::StockItem](docs/StockItem.md)
 - [Beanie::StockLocation](docs/StockLocation.md)
 - [Beanie::StockSupplier](docs/StockSupplier.md)
 - [Beanie::Supplier](docs/Supplier.md)
 - [Beanie::SupplierAddress](docs/SupplierAddress.md)
 - [Beanie::SupplierNote](docs/SupplierNote.md)
 - [Beanie::VatRecord](docs/VatRecord.md)
 - [Beanie::VatReturn](docs/VatReturn.md)
 - [Beanie::WorkCentre](docs/WorkCentre.md)
 - [Beanie::WorkCentreGroup](docs/WorkCentreGroup.md)
 - [Beanie::AddressBlockInput](docs/AddressBlockInput.md)
 - [Beanie::BankAccount](docs/BankAccount.md)
 - [Beanie::BankStatementDataInput](docs/BankStatementDataInput.md)
 - [Beanie::BankStatementInput](docs/BankStatementInput.md)
 - [Beanie::BeanieTaskInput](docs/BeanieTaskInput.md)
 - [Beanie::BillOfMaterialInput](docs/BillOfMaterialInput.md)
 - [Beanie::BillableInput](docs/BillableInput.md)
 - [Beanie::BomItemInput](docs/BomItemInput.md)
 - [Beanie::CustomerAddressInput](docs/CustomerAddressInput.md)
 - [Beanie::CustomerInput](docs/CustomerInput.md)
 - [Beanie::CustomerLedgerInput](docs/CustomerLedgerInput.md)
 - [Beanie::CustomerNoteInput](docs/CustomerNoteInput.md)
 - [Beanie::DeliveryNoteInput](docs/DeliveryNoteInput.md)
 - [Beanie::DeliveryNoteItemInput](docs/DeliveryNoteItemInput.md)
 - [Beanie::DocumentInput](docs/DocumentInput.md)
 - [Beanie::FixedAssetInput](docs/FixedAssetInput.md)
 - [Beanie::JournalInput](docs/JournalInput.md)
 - [Beanie::JournalItemInput](docs/JournalItemInput.md)
 - [Beanie::NominalAccountCategoryInput](docs/NominalAccountCategoryInput.md)
 - [Beanie::NominalAccountInput](docs/NominalAccountInput.md)
 - [Beanie::ProductCategoryInput](docs/ProductCategoryInput.md)
 - [Beanie::ProductInput](docs/ProductInput.md)
 - [Beanie::ProductPriceInput](docs/ProductPriceInput.md)
 - [Beanie::ProductVariantInput](docs/ProductVariantInput.md)
 - [Beanie::ProductionOrderInput](docs/ProductionOrderInput.md)
 - [Beanie::ProductionOrderLogInput](docs/ProductionOrderLogInput.md)
 - [Beanie::PurchaseInvoiceInput](docs/PurchaseInvoiceInput.md)
 - [Beanie::PurchaseOrderInput](docs/PurchaseOrderInput.md)
 - [Beanie::PurchaseOrderItemInput](docs/PurchaseOrderItemInput.md)
 - [Beanie::ReceivedGoodsInput](docs/ReceivedGoodsInput.md)
 - [Beanie::SalesInvoiceInput](docs/SalesInvoiceInput.md)
 - [Beanie::SalesInvoiceItemInput](docs/SalesInvoiceItemInput.md)
 - [Beanie::SalesOrderInput](docs/SalesOrderInput.md)
 - [Beanie::SalesOrderItemInput](docs/SalesOrderItemInput.md)
 - [Beanie::ShippingCentreInput](docs/ShippingCentreInput.md)
 - [Beanie::StockAdjustmentInput](docs/StockAdjustmentInput.md)
 - [Beanie::StockCategoryInput](docs/StockCategoryInput.md)
 - [Beanie::StockImageInput](docs/StockImageInput.md)
 - [Beanie::StockItemInput](docs/StockItemInput.md)
 - [Beanie::StockLocationInput](docs/StockLocationInput.md)
 - [Beanie::StockSupplierInput](docs/StockSupplierInput.md)
 - [Beanie::SupplierAddressInput](docs/SupplierAddressInput.md)
 - [Beanie::SupplierInput](docs/SupplierInput.md)
 - [Beanie::SupplierNoteInput](docs/SupplierNoteInput.md)
 - [Beanie::VatRecordInput](docs/VatRecordInput.md)
 - [Beanie::VatReturnInput](docs/VatReturnInput.md)
 - [Beanie::WorkCentreGroupInput](docs/WorkCentreGroupInput.md)
 - [Beanie::WorkCentreInput](docs/WorkCentreInput.md)


## Documentation for Authorization


### api_key

- **Type**: API key
- **API key parameter name**: ApiKey
- **Location**: HTTP header

